@@ -418,7 +418,7 @@ def common_check_config(obj, config, item, all_config, all_io_objects):
                 ex = FirewallError(errors.INVALID_ICMPTYPE,
                         "{} '{}': '{}' not among existing ICMP types".format(
                             obj_type, obj.name, icmptype))
-                if icmptype in all_io_objects.get("icmptypes_unsupported", {}):
+                if icmptype in all_io_objects.get("runtime", {}).get("icmptypes_unsupported", {}):
                     log.debug1("{} (unsupported)".format(ex))
                 else:
                     raise ex
@@ -453,7 +453,7 @@ def common_check_config(obj, config, item, all_config, all_io_objects):
                     ex = FirewallError(errors.INVALID_ICMPTYPE,
                             "{} '{}': '{}' not among existing ICMP types".format(
                                 obj_type, obj.name, obj_rich.element.name))
-                    if obj_rich.element.name in all_io_objects.get("icmptypes_unsupported", {}):
+                    if obj_rich.element.name in all_io_objects.get("runtime", {}).get("icmptypes_unsupported", {}):
                         log.debug1("{} (unsupported)".format(ex))
                     else:
                         raise ex
@@ -463,7 +463,7 @@ def common_check_config(obj, config, item, all_config, all_io_objects):
                         ex = FirewallError(errors.INVALID_ICMPTYPE,
                                            "{} '{}': rich rule family '{}' conflicts with icmp type '{}'".format(
                                                 obj_type, obj.name, obj_rich.family, obj_rich.element.name))
-                        ict_unsupported = all_io_objects.get("icmptypes_unsupported", {}).get(obj_rich.element.name)
+                        ict_unsupported = all_io_objects.get("runtime", {}).get("icmptypes_unsupported", {}).get(obj_rich.element.name)
                         if ict_unsupported and ict_unsupported.destination and \
                            obj_rich.family in ict_unsupported.destination:
                             log.debug1("{} (unsupported)".format(ex))
@@ -882,7 +882,8 @@ class Policy(IO_Object):
                         continue
                     if zone not in all_io_objects["zones"]:
                         raise FirewallError(errors.INVALID_ZONE, "Policy '{}': Zone '{}' does not exist.".format(self.name, zone))
-                    if all_io_objects["zones"][zone].interfaces:
+                    if all_io_objects["conf"].get("FirewallBackend") != "nftables" \
+                       and all_io_objects["zones"][zone].interfaces:
                         raise FirewallError(errors.INVALID_ZONE, "Policy '{}': 'masquerade' cannot be used because ingress zone '{}' has assigned interfaces. ".format(self.name, zone))
         elif item == "rich_rules":
             for rule in config:
@@ -902,7 +903,8 @@ class Policy(IO_Object):
                                 continue
                             if zone not in all_io_objects["zones"]:
                                 raise FirewallError(errors.INVALID_ZONE, "Policy '{}': Zone '{}' does not exist.".format(self.name, zone))
-                            if all_io_objects["zones"][zone].interfaces:
+                            if all_io_objects["conf"].get("FirewallBackend") != "nftables" \
+                               and all_io_objects["zones"][zone].interfaces:
                                 raise FirewallError(errors.INVALID_ZONE, "Policy '{}': 'masquerade' cannot be used because ingress zone '{}' has assigned interfaces. ".format(self.name, zone))
                 elif obj.element and isinstance(obj.element, rich.Rich_ForwardPort):
                     if "egress_zones" in all_config:
